%define basen cddlib
%define major 0
%define libname %mklibname %{basen} %{major}
%define develname %mklibname %{basen} -d

Name:           cddlib
Version:        0.94j
Release:        %mkrel 1
Summary:        A library for generating all vertices in convex polyhedrons
Group:          Sciences/Mathematics
License:        GPLv2+
URL:            https://www.inf.ethz.ch/personal/fukudak/cdd_home/
Source0:        https://github.com/cddlib/cddlib/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        cdd_both_reps.c
Patch0:         %{name}-sagemath.patch

BuildRequires:  gcc
BuildRequires:  gmp-devel
BuildRequires:  libtool
BuildRequires:  texlive-texmf

%description
The C-library cddlib is a C implementation of the Double Description
Method of Motzkin et al. for generating all vertices (i.e. extreme points)
and extreme rays of a general convex polyhedron in R^d given by a system
of linear inequalities:

   P = { x=(x1, ..., xd)^T :  b - A  x  >= 0 }

where A is a given m x d real matrix, b is a given m-vector
and 0 is the m-vector of all zeros.

The program can be used for the reverse operation (i.e. convex hull
computation). This means that one can move back and forth between
an inequality representation and a generator (i.e. vertex and ray)
representation of a polyhedron with cdd. Also, cdd can solve a linear
programming problem, i.e. a problem of maximizing and minimizing
a linear function over P.

%package -n %{libname}
Summary:        cddlib libraries
Group:		    System/Libraries

%description -n %{libname}
The C-library cddlib is a C implementation of the Double Description
Method of Motzkin et al. for generating all vertices (i.e. extreme points)
and extreme rays of a general convex polyhedron in R^d given by a system
of linear inequalities:

   P = { x=(x1, ..., xd)^T :  b - A  x  >= 0 }

where A is a given m x d real matrix, b is a given m-vector
and 0 is the m-vector of all zeros.

The program can be used for the reverse operation (i.e. convex hull
computation). This means that one can move back and forth between
an inequality representation and a generator (i.e. vertex and ray)
representation of a polyhedron with cdd. Also, cdd can solve a linear
programming problem, i.e. a problem of maximizing and minimizing
a linear function over P.

%package -n %{develname}
Summary:        Headers for cddlib
Group:		    Development/Libraries
Requires:       gmp-devel
Requires:       %{libname} = %{version}-%{release}
Provides:       %{basen}-devel = %{version}-%{release}


%description -n %{develname}
Include files for cddlib.


%package static
Summary:        Static libraries for cddlib
Group:		    System/Libraries

%description static
Static libraries for cddlib.


%package tools
Summary:        Sample binaries that use cddlib
Group:          Sciences/Mathematics
Requires:       %{libname} = %{version}-%{release}

%description tools
Sample binaries that use cddlib.


%prep
%setup -q
%patch0 -p1

# Regenerate Makefile.in files due to patched Makefile.am files
autoreconf -ifs

# Install sagemath extra source
cp -p %{SOURCE1} src

# Fix the FSF's address
for f in `find . -type f -print0 | xargs -0 grep -Fl '675 Mass'`; do
  sed -i.orig \
    's/675 Mass Ave, Cambridge, MA 02139/51 Franklin Street, Suite 500, Boston, MA  02110-1335/' \
    $f
  touch -r $f.orig $f
  rm -f $f.orig
done

# Force rebuilding of the documentation
rm -f doc/cddlibman.pdf


%build
%configure2_5x

# Get rid of undesirable hardcoded rpaths; workaround libtool reordering
# -Wl,--as-needed after all the libraries.
sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    -e 's|CC="\(.*g..\)"|CC="\1 -Wl,--as-needed"|' \
    -i libtool

make %{?_smp_mflags}

# Need one more invocation of pdflatex to get cross references correct
pushd doc
pdflatex cddlibman
popd


%install
make install DESTDIR=$RPM_BUILD_ROOT INSTALL="install -p"
mkdir $RPM_BUILD_ROOT%{_includedir}/cddlib
mv $RPM_BUILD_ROOT%{_includedir}/{cdd,cdd_f,cddmp,cddmp_f,cddtypes,cddtypes_f,setoper,splitmix64}.h \
  $RPM_BUILD_ROOT%{_includedir}/cddlib/
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la

# Do not prematurely install documentation
rm -fr $RPM_BUILD_ROOT%{_pkgdocdir}


%files -n %{libname}
%{_libdir}/*.so.%{major}*


%files -n %{develname}
%{_includedir}/cddlib
%{_libdir}/*.so


%files static
%{_libdir}/libcdd.a
%{_libdir}/libcddgmp.a


%files tools
%{_bindir}/*
%{_datadir}/doc

%changelog
* Mon Jan 06 2020 tex - 0.94j-1pclos2020
- create
